@@ -2,7 +2,8 @@
 #' Format and organize WQP arguments that are passed in as \code{...}.
 #'
 #' @keywords internal
-readWQPdots <- function(...) {
+readWQPdots <- function(..., legacy = TRUE) {
+  
   if (length(list(...)) == 0) {
     stop("No arguments supplied")
   }
@@ -13,35 +14,63 @@ readWQPdots <- function(...) {
     service <- matchReturn$service
     matchReturn$service <- NULL
   } else {
-    service <- "Result"
+    if(legacy){
+      service <- "Result"
+    } else {
+      service <- "ResultWQX3"
+    }
+    
   }
   
   if ("dataProfile" %in% names(matchReturn)) {
     profile <- matchReturn$dataProfile
     if (profile == "activityAll") {
-      service <- "Activity"
+      service <- "ActivityWQX3"
       matchReturn$service <- NULL
-    } else if (profile %in% c(
-      "resultPhysChem",
-      "biological",
-      "narrowResult"
-    )) {
+    } else if (profile %in% c("resultPhysChem","biological","narrowResult")) {
       service <- "Result"
       matchReturn$service <- NULL
-    }
-  }
+    } else if(profile %in% c("fullPhysChem", "narrow", "basicPhysChem")){
+      service <- "ResultWQX3"
+      matchReturn$service <- NULL      
+    } 
+  } 
   
   match.arg(service, c(
     "Result", "Station", "Activity", "Organization",
     "ActivityMetric", "SiteSummary",
     "Project", "ProjectMonitoringLocationWeighting",
-    "ResultDetectionQuantitationLimit", "BiologicalMetric"
+    "ResultDetectionQuantitationLimit", "BiologicalMetric",
+    "ResultWQX3", "StationWQX3", "ActivityWQX3"
   ))
-
+  
+  names(matchReturn)[names(matchReturn) == "bbox"] <- "bBox"
+    
+  bbox <- "bBox" %in% names(matchReturn)
+  if(bbox){
+    values_bbox <- sapply(matchReturn["bBox"], function(x) as.character(paste0(eval(x), collapse = ",")))
+    matchReturn <- matchReturn[names(matchReturn) != "bBox"]
+  }
+  
+  if(!legacy){
+    new_list <- rep(list(NA),length(unlist(matchReturn)))
+    names_list <- c()
+    i <- 1
+    for(arg in names(matchReturn)){
+      for(val in as.character(matchReturn[[arg]])) {
+        new_list[[i]] <- val
+        names_list <- c(names_list, arg)
+        i <- i + 1
+      }
+    }
+    names(new_list) <- names_list
+    matchReturn <- new_list
+  }
+  
   values <- sapply(matchReturn, function(x) as.character(paste0(eval(x), collapse = ";")))
   
-  if ("bBox" %in% names(values)) {
-    values["bBox"] <- gsub(pattern = ";", replacement = ",", x = values["bBox"])
+  if (bbox) {
+    values <- c(values, values_bbox)
   }
   
   values <- checkWQPdates(values)
@@ -50,6 +79,7 @@ readWQPdots <- function(...) {
   names(values)[names(values) == "siteNumbers"] <- "siteid"
   names(values)[names(values) == "parameterCd"] <- "pCode"
   names(values)[names(values) == "USGSPCode"] <- "pCode"
+  
 
   names(values)[names(values) == "stateCd"] <- "statecode"
   if ("statecode" %in% names(values)) {
@@ -64,7 +94,7 @@ readWQPdots <- function(...) {
   if (all(c("countycode", "statecode") %in% names(values))) {
     stCd <- gsub("US:", "", values["statecode"])
     # This will error if more than 1 state is requested
-    # It's possible that someone could requst more than one state
+    # It's possible that someone could request more than one state
     # in WQP, but if they also then request county codes,
     # it gets really confusing, and the WQP developers don't recommend.
     values["countycode"] <- paste(values["statecode"],
@@ -73,13 +103,6 @@ readWQPdots <- function(...) {
     )
   }
 
-  if ("zip" %in% names(values)) {
-    if (is.logical(values["zip"])) {
-      values["zip"] <- ifelse(values["zip"], "yes", "no")
-    }
-  } else {
-    values["zip"] <- "yes"
-  }
-
   return(list(values = values, service = service))
 }
+
