@@ -141,11 +141,25 @@ test_that("WQP qw tests", {
   nameToUse <- "Specific conductance"
   pcodeToUse <- "00095"
 
-  INFO_WQP <- readWQPqw("USGS-04024315", pcodeToUse, startDate = "", endDate = "")
-  expect_is(INFO_WQP$ActivityStartDateTime, "POSIXct")
+  INFO_WQP <- readWQPqw("USGS-04024315", pcodeToUse, 
+                        startDate = "", endDate = "", legacy = FALSE)
+  expect_is(INFO_WQP$Activity_StartDateTime, "POSIXct")
 
-  INFO2 <- readWQPqw("WIDNR_WQX-10032762", nameToUse, startDate = "", endDate = "")
-  expect_is(INFO2$ActivityStartDateTime, "POSIXct")
+  INFO2 <- readWQPqw("WIDNR_WQX-10032762", nameToUse, 
+                     startDate = "", endDate = "", legacy = FALSE)
+  expect_is(INFO2$Activity_StartDateTime, "POSIXct")
+  
+  df <- readWQPqw("USGS-04193500", parameterCd = "00665", legacy = FALSE)
+  expect_true(nrow(df) > 0)
+  
+  df2 <- readWQPqw("USGS-05427718", parameterCd = "all")
+  expect_true(nrow(df2) > 0)
+  
+  #Empty legacy:
+  df3 <- readWQPqw(siteNumbers = "USGS-385032115220501",
+                   parameterCd = "all", legacy = TRUE)
+  expect_true(nrow(df3) == 0)
+  
 })
 
 context("readNWISstat tests")
@@ -344,6 +358,7 @@ test_that("Construct NWIS urls", {
     startDate, endDate, "dv",
     statCd = c("00003", "00001")
   )
+  
   # nolint start: line_length_linter
   expect_equal(url_daily, "https://waterservices.usgs.gov/nwis/dv/?site=01594440&format=waterml,1.1&ParameterCd=00060,00010&StatCd=00003,00001&startDT=1985-01-01")
 
@@ -353,55 +368,11 @@ test_that("Construct NWIS urls", {
     "https://nwis.waterservices.usgs.gov/nwis/iv/?site=01594440&format=waterml,1.1&ParameterCd=00060,00010&startDT=2012-06-28&endDT=2012-06-30"
   )
 
-  url_qw_single <- constructNWISURL(siteNumber, "01075", startDate, endDate, "qw")
-  expect_equal(url_qw_single, "https://nwis.waterdata.usgs.gov/nwis/qwdata?search_site_no=01594440&search_site_no_match_type=exact&multiple_parameter_cds=01075&param_cd_operator=AND&list_of_search_criteria=search_site_no,multiple_parameter_cds&group_key=NONE&sitefile_output_format=html_table&column_name=agency_cd&column_name=site_no&column_name=station_nm&inventory_output=0&rdb_inventory_output=file&TZoutput=0&pm_cd_compare=Greater%20than&radio_parm_cds=previous_parm_cds&qw_attributes=0&format=rdb&rdb_qw_attributes=expanded&date_format=YYYY-MM-DD&rdb_compression=value&qw_sample_wide=0&begin_date=1985-01-01")
-
-  url_qw <- constructNWISURL(
-    siteNumber, c("01075", "00029", "00453"),
-    startDate, endDate, "qw"
-  )
-  expect_equal(url_qw, "https://nwis.waterdata.usgs.gov/nwis/qwdata?search_site_no=01594440&search_site_no_match_type=exact&multiple_parameter_cds=01075,00029,00453&param_cd_operator=OR&list_of_search_criteria=search_site_no,multiple_parameter_cds&group_key=NONE&sitefile_output_format=html_table&column_name=agency_cd&column_name=site_no&column_name=station_nm&inventory_output=0&rdb_inventory_output=file&TZoutput=0&pm_cd_compare=Greater%20than&radio_parm_cds=previous_parm_cds&qw_attributes=0&format=rdb&rdb_qw_attributes=expanded&date_format=YYYY-MM-DD&rdb_compression=value&qw_sample_wide=0&begin_date=1985-01-01")
-
   url_daily_tsv <- constructNWISURL(siteNumber, pCode, startDate, endDate, "dv",
     statCd = c("00003", "00001"), format = "tsv"
   )
   expect_equal(url_daily_tsv, "https://waterservices.usgs.gov/nwis/dv/?site=01594440&format=rdb,1.0&ParameterCd=00060,00010&StatCd=00003,00001&startDT=1985-01-01")
 
-  setAccess("internal")
-  url_rating <- constructNWISURL(siteNumber, service = "rating", ratingType = "base")
-  expect_equal(url_rating, "https://waterdata.usgs.gov/nwisweb/get_ratings/?Access=3&site_no=01594440&file_type=base")
-  url_peak <- constructNWISURL(siteNumber, service = "peak")
-  expect_equal(url_peak, "https://nwis.waterdata.usgs.gov/usa/nwis/peak/?Access=3&site_no=01594440&range_selection=date_range&format=rdb")
-
-  url_meas <- constructNWISURL(siteNumber, service = "meas")
-  expect_equal(url_meas, "https://waterdata.usgs.gov/nwis/measurements/?Access=3&site_no=01594440&range_selection=date_range&format=rdb_expanded")
-
-  urlQW <- constructNWISURL("450456092225801", "70300",
-    startDate = "", endDate = "",
-    "qw", expanded = TRUE
-  )
-  expect_equal(urlQW, "https://nwis.waterdata.usgs.gov/nwis/qwdata?Access=3&search_site_no=450456092225801&search_site_no_match_type=exact&multiple_parameter_cds=70300&param_cd_operator=AND&list_of_search_criteria=search_site_no,multiple_parameter_cds&group_key=NONE&sitefile_output_format=html_table&column_name=agency_cd&column_name=site_no&column_name=station_nm&inventory_output=0&rdb_inventory_output=file&TZoutput=0&pm_cd_compare=Greater%20than&radio_parm_cds=previous_parm_cds&qw_attributes=0&format=rdb&rdb_qw_attributes=expanded&date_format=YYYY-MM-DD&rdb_compression=value&qw_sample_wide=0")
-
-  setAccess("cooperator")
-  urlQW <- constructNWISURL("450456092225801", "70300",
-    startDate = "", endDate = "", "qw", expanded = TRUE
-  )
-  expect_equal(urlQW, "https://nwis.waterdata.usgs.gov/nwis/qwdata?Access=1&search_site_no=450456092225801&search_site_no_match_type=exact&multiple_parameter_cds=70300&param_cd_operator=AND&list_of_search_criteria=search_site_no,multiple_parameter_cds&group_key=NONE&sitefile_output_format=html_table&column_name=agency_cd&column_name=site_no&column_name=station_nm&inventory_output=0&rdb_inventory_output=file&TZoutput=0&pm_cd_compare=Greater%20than&radio_parm_cds=previous_parm_cds&qw_attributes=0&format=rdb&rdb_qw_attributes=expanded&date_format=YYYY-MM-DD&rdb_compression=value&qw_sample_wide=0")
-
-  setAccess("USGS")
-  urlQW <- constructNWISURL("450456092225801", "70300",
-    startDate = "",
-    endDate = "", "qw", expanded = TRUE
-  )
-  expect_equal(urlQW, "https://nwis.waterdata.usgs.gov/nwis/qwdata?Access=2&search_site_no=450456092225801&search_site_no_match_type=exact&multiple_parameter_cds=70300&param_cd_operator=AND&list_of_search_criteria=search_site_no,multiple_parameter_cds&group_key=NONE&sitefile_output_format=html_table&column_name=agency_cd&column_name=site_no&column_name=station_nm&inventory_output=0&rdb_inventory_output=file&TZoutput=0&pm_cd_compare=Greater%20than&radio_parm_cds=previous_parm_cds&qw_attributes=0&format=rdb&rdb_qw_attributes=expanded&date_format=YYYY-MM-DD&rdb_compression=value&qw_sample_wide=0")
-
-  setAccess("public")
-  urlQW <- constructNWISURL("450456092225801", "70300",
-    startDate = "",
-    endDate = "", "qw", expanded = TRUE
-  )
-  expect_equal(urlQW, "https://nwis.waterdata.usgs.gov/nwis/qwdata?search_site_no=450456092225801&search_site_no_match_type=exact&multiple_parameter_cds=70300&param_cd_operator=AND&list_of_search_criteria=search_site_no,multiple_parameter_cds&group_key=NONE&sitefile_output_format=html_table&column_name=agency_cd&column_name=site_no&column_name=station_nm&inventory_output=0&rdb_inventory_output=file&TZoutput=0&pm_cd_compare=Greater%20than&radio_parm_cds=previous_parm_cds&qw_attributes=0&format=rdb&rdb_qw_attributes=expanded&date_format=YYYY-MM-DD&rdb_compression=value&qw_sample_wide=0")
-
   url_use <- constructUseURL(
     years = c(1990, 1995),
     stateCd = "Ohio",
@@ -420,15 +391,15 @@ test_that("Construct WQP urls", {
   startDate <- "1985-01-01"
   endDate <- ""
   pCode <- c("00060", "00010")
+  
   url_wqp <- constructWQPURL(
     paste("USGS", site_id, sep = "-"),
     c("01075", "00029", "00453"),
-    startDate, endDate
-  )
+    startDate, endDate, legacy = FALSE)
   # nolint start: line_length_linter
   expect_equal(
     url_wqp,
-    "https://www.waterqualitydata.us/data/Result/search?siteid=USGS-01594440&pCode=01075;00029;00453&startDateLo=01-01-1985&mimeType=tsv&zip=yes"
+    "https://www.waterqualitydata.us/wqx3/Result/search?siteid=USGS-01594440&pCode=01075&pCode=00029&pCode=00453&startDateLo=01-01-1985&mimeType=csv&dataProfile=basicPhysChem"
   )
 
   # Multiple characteristicNames
@@ -436,14 +407,15 @@ test_that("Construct WQP urls", {
     "Temperature", "Temperature, sample", "Temperature, water",
     "Temperature, water, deg F"
   )
+  
   obs_url_orig <- constructWQPURL(
     siteNumbers = c("IIDFG-41WSSPAHS", "USGS-02352560"),
-    parameterCd = c("Temperature", "Temperature, sample", "Temperature, water", "Temperature, water, deg F"),
-    "", ""
-  )
+    parameterCd = charNames,
+    startDate = "", endDate =  "", legacy = FALSE)
+  
   expect_equal(
     obs_url_orig,
-    "https://www.waterqualitydata.us/data/Result/search?siteid=IIDFG-41WSSPAHS;USGS-02352560&characteristicName=Temperature;Temperature%2C%20sample;Temperature%2C%20water;Temperature%2C%20water%2C%20deg%20F&mimeType=tsv&zip=yes"
+    "https://www.waterqualitydata.us/wqx3/Result/search?siteid=IIDFG-41WSSPAHS&siteid=USGS-02352560&characteristicName=Temperature&characteristicName=Temperature%2C%20sample&characteristicName=Temperature%2C%20water&characteristicName=Temperature%2C%20water%2C%20deg%20F&mimeType=csv&dataProfile=basicPhysChem"
   )
 
   # nolint end
@@ -458,19 +430,14 @@ test_that("Construct WQP urls", {
   url_wqp <- constructWQPURL(
     paste("USGS", siteNumber, sep = "-"),
     c("01075", "00029", "00453"),
-    startDate, endDate
-  )
+    startDate, endDate,legacy = FALSE)
+  
   # nolint start: line_length_linter
   expect_equal(
     url_wqp,
-    "https://www.waterqualitydata.us/data/Result/search?siteid=USGS-01594440&pCode=01075;00029;00453&startDateLo=01-01-1985&mimeType=tsv&zip=yes"
+    "https://www.waterqualitydata.us/wqx3/Result/search?siteid=USGS-01594440&pCode=01075&pCode=00029&pCode=00453&startDateLo=01-01-1985&mimeType=csv&dataProfile=basicPhysChem"
   )
 
-  rawSampleURL_Zip <- constructWQPURL("USGS-01594440", "01075", "", "", TRUE)
-  expect_equal(
-    rawSampleURL_Zip,
-    "https://www.waterqualitydata.us/data/Result/search?siteid=USGS-01594440&pCode=01075&mimeType=tsv&zip=yes"
-  )
   # nolint end
 })
 
@@ -494,7 +461,7 @@ test_that("pCode Stuff", {
   expect_equal(paramINFO$parameter_group_nm[3:4], c(NA_character_, NA_character_))
 
   paramINFO <- readNWISpCode("all")
-  expect_true(nrow(paramINFO) > 24000)
+  expect_true(nrow(paramINFO) > 20000)
   expect_equal(
     attr(paramINFO, "url"),
     "https://help.waterdata.usgs.gov/code/parameter_cd_query?fmt=rdb&group_cd=%"
